<?php

/**
 * Field handler that displays links to act upon a follow-up record.
 */
class followup_handler_field_followup_record_actions extends views_handler_field {

  function query() {
    $this->ensure_my_table();
    $this->add_additional_fields(array('followup', 'nid', 'target_nid', 'sequence', 'status'));
  }

  function render($values) {
    global $user;
    $actions = array();
    switch ($values->{$this->aliases['status']}) {
      case 'due':
        // Load corresponding follow-up
        $followup = followup_load($values->{$this->aliases['followup']});
        // Verify permission to create nodes of the target type
        if (user_access('create ' . $followup->target_type . ' content')) {
          $link = array();
          // Add integration with nodereference_url
          if (module_exists('nodereference_url') && $followup->target_reference_field) {
            $nodereference_url_field = content_fields($followup->target_reference_field, $followup->target_type);
            // Nodereference URL needs this for some reason
            $nodereference_url_field['widget']['node_link']['full'] = 1;
            $node = node_load($values->{$this->aliases['nid']});
            $link = nodereference_url_build_link($node, $nodereference_url_field);
          }
          if (!empty($link)) {
            $link = $link['href'];
          }
          else {
            $link = 'node/add/' . str_replace('_', '-', $followup->target_type);
          }
          $actions[] = l('Add', $link, array('query' => array('followup' => $values->{$this->aliases['nid']} . ':' . $values->{$this->aliases['sequence']})));
        }
      case 'scheduled':
      case 'cancelled':
        if (user_access('administer followup')) {
          $actions[] = l('Edit schedule', 'node/' . $values->{$this->aliases['nid']} . '/followup/' . $values->{$this->aliases['sequence']});
        }
        break;
      case 'complete':
        $actions[] = l('View', 'node/' . $values->{$this->aliases['target_nid']});
        break;
    }
    return theme_item_list($actions);
  }

}
